============================================================================
``psyclone.psyir.transformations.fold_conditional_return_expressions_trans``
============================================================================

.. automodule:: psyclone.psyir.transformations.fold_conditional_return_expressions_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.fold_conditional_return_expressions_trans


Classes
=======

- :py:class:`FoldConditionalReturnExpressionsTrans`:
  Provides a transformation that folds conditional expressions with only


.. autoclass:: FoldConditionalReturnExpressionsTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: FoldConditionalReturnExpressionsTrans
      :parts: 1
